"""
THIS IS A FILE WITH ALPHABETS OF CORRESPONDING LANGUAGES (ISO 639-1)
"""

ALPHABETS = {

    "RU": {
        "lower": "абвгдеёжзийклмнопрстуфхцчшщъыьэюя",
        "upper": "АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ"
    },

    "EN": {
        "lower": "abcdefghijklmnopqrstuvwxyz",
        "upper": "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
    }

}
